import { default as ReactQuill } from 'react-quill';
export type AnswerType = 'text' | 'radio' | 'checkbox' | 'select' | 'dragdrop' | 'upload' | 'sortorder' | 'draw' | 'memory';
export declare const AnswerTypeList: string[];
export declare const QuestionTypeList: string[];
export type QuestionLayoutType = 'Fullsize' | 'Halfsize';
export declare const QuestionLayoutList: string[];
export declare const ContenTypeList: string[];
export type QuizType = 'practice' | 'exam' | 'editor' | 'view';
export declare const ITEMS_SEPARATOR = "|";
export declare const CORRECT_ANSWER = "---Correct---";
export interface IQuestion {
    id: number | string;
    question_type?: string;
    layout?: string;
    timeout?: number;
    content?: string;
    content_type?: string;
    url?: string;
    audio?: string;
    description?: string;
    question?: string;
    answer_type?: string;
    options?: string[];
    correct_answer?: string;
    correct_point?: number;
    answer?: string;
    correct?: boolean;
}
export interface IQuestionAnswer {
    id: number | string;
    answer: string;
    correct?: boolean;
    point?: number;
}
export interface IQuiz {
    quiz_id?: string;
    title?: string;
    description?: string;
    audio?: string;
    background?: string;
    questions: IQuestion[];
    max_point?: number;
    suffle?: boolean;
    max_question?: number;
    duration?: number;
    question_timeout?: number;
    results?: IQuizResults;
    type?: QuizType;
    onSubmit?: (quiz: IQuizResults) => void;
    onSave?: (quiz: IQuiz) => void;
    onChange?: (quiz: IQuiz) => void;
}
export interface IQuizData {
    quiz_id?: string;
    questions: IQuestion[];
    questionIndex: number;
    answers: IQuestionAnswer[];
    startAt: number;
    isFetching: boolean;
    finished: boolean;
    results: IQuizResults;
}
export interface IQuizResults {
    quiz_id?: string;
    participant_id?: string;
    participant_name?: string;
    participant_email?: string;
    total_point?: number;
    total_questions?: number;
    total_answers?: number;
    correct_answers?: number;
    start_time?: Date;
    end_time?: Date;
    duration?: number;
    answers: IQuestionAnswer[];
}
export type ModalType = 'question' | 'result' | 'submit';
export interface IModalProps {
    title?: string;
    message?: string | null | JSX.Element;
    type?: ModalType;
    buttonTitle?: string;
    onConfirm?: () => void;
    onClose: () => void;
    children?: React.ReactNode;
}
export interface IQuizProps {
    quiz: IQuiz;
    openModal: (type: ModalType, content: string | JSX.Element) => void;
    closeModal: () => void;
    onSubmit?: boolean;
    showResult?: () => void;
}
export interface IQuestionProps {
    quiz: IQuiz;
    question?: IQuestion;
    className?: string;
    answer?: IQuestionAnswer;
    finished?: boolean;
    isLoading?: boolean;
    optionsRef?: Array<React.MutableRefObject<HTMLButtonElement | null>>;
    isInitialLoad?: boolean;
    readonly?: boolean;
    checkAnswer?: (e: any) => void;
    updateAnswer?: (e: any) => void;
    setMediaPlaying?: (playing: boolean) => void;
    setFinished?: () => void;
}
export interface IEditorHTML {
    onImage?: (quill: ReactQuill, onResult: (value: {
        url: string;
        name: string;
    }) => void) => void;
    onVideo?: (quill: ReactQuill, onResult: (value: {
        url: string;
        name: string;
    }) => void) => void;
}
